==> jc-1.4.0.tar.gz: java/awt/color/ICC__5fProfileRGB.h <==
// public class java.awt.color.ICC_ProfileRGB

// class file dependencies
// @dep_class 7f6d2ca910e6237f java_awt_color_ICC__5fProfile
// @dep_class d597e7f826d89e34 java_awt_color_ICC__5fProfileRGB
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_color_ICC__5fProfile

#include "java/awt/color/ICC__5fProfile.h"

#ifndef _JC_java_awt_color_ICC__5fProfileRGB_H_
#define _JC_java_awt_color_ICC__5fProfileRGB_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$sub_refs	_jc_java_awt_color_ICC__5fProfileRGB$sub_refs;
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$sub_nonrefs	_jc_java_awt_color_ICC__5fProfileRGB$sub_nonrefs;
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$refs	_jc_java_awt_color_ICC__5fProfileRGB$refs;
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$nonrefs	_jc_java_awt_color_ICC__5fProfileRGB$nonrefs;
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$object	_jc_java_awt_color_ICC__5fProfileRGB$object;

typedef struct _jc_java_awt_color_ICC__5fProfileRGB$fields_struct	_jc_java_awt_color_ICC__5fProfileRGB$fields_struct;
typedef const struct _jc_java_awt_color_ICC__5fProfileRGB$vmethods	_jc_java_awt_color_ICC__5fProfileRGB$vmethods;
typedef const struct _jc_java_awt_color_ICC__5fProfileRGB$vtable	_jc_java_awt_color_ICC__5fProfileRGB$vtable;
typedef const struct _jc_java_awt_color_ICC__5fProfileRGB$vtype	_jc_java_awt_color_ICC__5fProfileRGB$vtype;

// Class fields structure
struct _jc_java_awt_color_ICC__5fProfileRGB$fields_struct {
	jlong	serialVersionUID;
	jint	BLUECOMPONENT;
	jint	GREENCOMPONENT;
	jint	REDCOMPONENT;
};
extern _jc_java_awt_color_ICC__5fProfileRGB$fields_struct _jc_java_awt_color_ICC__5fProfileRGB$class_fields;

// Constructors
extern void _jc_java_awt_color_ICC__5fProfileRGB$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint);
extern void _jc_java_awt_color_ICC__5fProfileRGB$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, struct _jc_byte_array *);

// Virtual methods
extern _jc_object_array *_jc_java_awt_color_ICC__5fProfileRGB$method$createMatrix$a580920f28cc48ac(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *);
extern jfloat _jc_java_awt_color_ICC__5fProfileRGB$method$getGamma$72a6818b34e4e10f(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint);
extern _jc_object_array *_jc_java_awt_color_ICC__5fProfileRGB$method$getMatrix$28dbca7ac8f09022(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *);
extern _jc_float_array *_jc_java_awt_color_ICC__5fProfileRGB$method$getMediaWhitePoint$04a03c9a4a91efe6(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *);
extern _jc_short_array *_jc_java_awt_color_ICC__5fProfileRGB$method$getTRC$e3d95df2cf805628(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$createMatrix$a580920f28cc48ac;
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$getGamma$72a6818b34e4e10f;
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$getMatrix$28dbca7ac8f09022;
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$getMediaWhitePoint$04a03c9a4a91efe6;
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$getTRC$e3d95df2cf805628;

// Virtual methods structure
struct _jc_java_awt_color_ICC__5fProfileRGB$vmethods {
	_jc_object_array	*(*createMatrix$a580920f28cc48ac)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *);
	jfloat	(*getGamma$72a6818b34e4e10f)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint);
	_jc_object_array	*(*getMatrix$28dbca7ac8f09022)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *);
	_jc_float_array	*(*getMediaWhitePoint$04a03c9a4a91efe6)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *);
	_jc_short_array	*(*getTRC$e3d95df2cf805628)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint);
};

// Vtable
struct _jc_java_awt_color_ICC__5fProfileRGB$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_color_ICC__5fProfile$vmethods	java_awt_color_ICC__5fProfile;
	_jc_java_awt_color_ICC__5fProfileRGB$vmethods	java_awt_color_ICC__5fProfileRGB;
};

// Vtype
struct _jc_java_awt_color_ICC__5fProfileRGB$vtype {
	_jc_type			type;
	_jc_java_awt_color_ICC__5fProfileRGB$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_color_ICC__5fProfileRGB$sub_refs {
	_jc_object_array	*matrix;
	_jc_float_array	*gamma;
	_jc_float_array	*whitePoint;
};

// Reference instance fields (object)
struct _jc_java_awt_color_ICC__5fProfileRGB$refs {
    _jc_java_awt_color_ICC__5fProfileRGB$sub_refs	java_awt_color_ICC__5fProfileRGB;
    _jc_java_awt_color_ICC__5fProfile$sub_refs	java_awt_color_ICC__5fProfile;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_color_ICC__5fProfileRGB$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_color_ICC__5fProfileRGB$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_color_ICC__5fProfile$sub_nonrefs	java_awt_color_ICC__5fProfile;
    _jc_java_awt_color_ICC__5fProfileRGB$sub_nonrefs	java_awt_color_ICC__5fProfileRGB;
};

// Object instance structure
struct _jc_java_awt_color_ICC__5fProfileRGB$object {
	_jc_java_awt_color_ICC__5fProfileRGB$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_color_ICC__5fProfileRGB$vtype	*vtype;
	_jc_java_awt_color_ICC__5fProfileRGB$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_color_ICC__5fProfileRGB$vtype _jc_java_awt_color_ICC__5fProfileRGB$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_color_ICC__5fProfileRGB, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_color_ICC__5fProfileRGB$class_object;

#endif	/* _JC_java_awt_color_ICC__5fProfileRGB_H_ */

==> jc-1.4.6.tar.gz: java/awt/color/ICC__5fProfileRGB.h <==
// public class java.awt.color.ICC_ProfileRGB

// class file dependencies
// @dep_class 7f6d2ca910e6237f java_awt_color_ICC__5fProfile
// @dep_class d597e7f826d89e34 java_awt_color_ICC__5fProfileRGB
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_color_ICC__5fProfile

#include "java/awt/color/ICC__5fProfile.h"

#ifndef _JC_java_awt_color_ICC__5fProfileRGB_H_
#define _JC_java_awt_color_ICC__5fProfileRGB_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$sub_refs	_jc_java_awt_color_ICC__5fProfileRGB$sub_refs;
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$sub_nonrefs	_jc_java_awt_color_ICC__5fProfileRGB$sub_nonrefs;
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$refs	_jc_java_awt_color_ICC__5fProfileRGB$refs;
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$nonrefs	_jc_java_awt_color_ICC__5fProfileRGB$nonrefs;
typedef struct _jc_java_awt_color_ICC__5fProfileRGB$object	_jc_java_awt_color_ICC__5fProfileRGB$object;

typedef struct _jc_java_awt_color_ICC__5fProfileRGB$fields_struct	_jc_java_awt_color_ICC__5fProfileRGB$fields_struct;
typedef const struct _jc_java_awt_color_ICC__5fProfileRGB$vmethods	_jc_java_awt_color_ICC__5fProfileRGB$vmethods;
typedef const struct _jc_java_awt_color_ICC__5fProfileRGB$vtable	_jc_java_awt_color_ICC__5fProfileRGB$vtable;
typedef const struct _jc_java_awt_color_ICC__5fProfileRGB$vtype	_jc_java_awt_color_ICC__5fProfileRGB$vtype;

// Class fields structure
struct _jc_java_awt_color_ICC__5fProfileRGB$fields_struct {
	jlong	serialVersionUID;
	jint	BLUECOMPONENT;
	jint	GREENCOMPONENT;
	jint	REDCOMPONENT;
};
extern _jc_java_awt_color_ICC__5fProfileRGB$fields_struct _jc_java_awt_color_ICC__5fProfileRGB$class_fields;

// Constructors
extern void _jc_java_awt_color_ICC__5fProfileRGB$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_color_ICC__5fProfileRGB$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_java_awt_color_ICC__5fProfileRGB$method$createMatrix$a580920f28cc48ac(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_color_ICC__5fProfileRGB$method$getGamma$72a6818b34e4e10f(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_awt_color_ICC__5fProfileRGB$method$getMatrix$28dbca7ac8f09022(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_java_awt_color_ICC__5fProfileRGB$method$getMediaWhitePoint$04a03c9a4a91efe6(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *) _JC_JCNI_ATTR;
extern _jc_short_array *_jc_java_awt_color_ICC__5fProfileRGB$method$getTRC$e3d95df2cf805628(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$createMatrix$a580920f28cc48ac;
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$getGamma$72a6818b34e4e10f;
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$getMatrix$28dbca7ac8f09022;
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$getMediaWhitePoint$04a03c9a4a91efe6;
extern _jc_method _jc_java_awt_color_ICC__5fProfileRGB$method_info$getTRC$e3d95df2cf805628;

// Virtual methods structure
struct _jc_java_awt_color_ICC__5fProfileRGB$vmethods {
	_jc_object_array	*(*createMatrix$a580920f28cc48ac)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *) _JC_JCNI_ATTR;
	jfloat	(*getGamma$72a6818b34e4e10f)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint) _JC_JCNI_ATTR;
	_jc_object_array	*(*getMatrix$28dbca7ac8f09022)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *) _JC_JCNI_ATTR;
	_jc_float_array	*(*getMediaWhitePoint$04a03c9a4a91efe6)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *) _JC_JCNI_ATTR;
	_jc_short_array	*(*getTRC$e3d95df2cf805628)(_jc_env *, struct _jc_java_awt_color_ICC__5fProfileRGB$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_color_ICC__5fProfileRGB$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_color_ICC__5fProfile$vmethods	java_awt_color_ICC__5fProfile;
	_jc_java_awt_color_ICC__5fProfileRGB$vmethods	java_awt_color_ICC__5fProfileRGB;
};

// Vtype
struct _jc_java_awt_color_ICC__5fProfileRGB$vtype {
	_jc_type			type;
	_jc_java_awt_color_ICC__5fProfileRGB$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_color_ICC__5fProfileRGB$sub_refs {
	_jc_object_array	*matrix;
	_jc_float_array	*gamma;
	_jc_float_array	*whitePoint;
};

// Reference instance fields (object)
struct _jc_java_awt_color_ICC__5fProfileRGB$refs {
    _jc_java_awt_color_ICC__5fProfileRGB$sub_refs	java_awt_color_ICC__5fProfileRGB;
    _jc_java_awt_color_ICC__5fProfile$sub_refs	java_awt_color_ICC__5fProfile;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_color_ICC__5fProfileRGB$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_color_ICC__5fProfileRGB$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_color_ICC__5fProfile$sub_nonrefs	java_awt_color_ICC__5fProfile;
    _jc_java_awt_color_ICC__5fProfileRGB$sub_nonrefs	java_awt_color_ICC__5fProfileRGB;
};

// Object instance structure
struct _jc_java_awt_color_ICC__5fProfileRGB$object {
	_jc_java_awt_color_ICC__5fProfileRGB$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_color_ICC__5fProfileRGB$vtype	*vtype;
	_jc_java_awt_color_ICC__5fProfileRGB$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_color_ICC__5fProfileRGB$vtype _jc_java_awt_color_ICC__5fProfileRGB$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_color_ICC__5fProfileRGB, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_color_ICC__5fProfileRGB$class_object;

#endif	/* _JC_java_awt_color_ICC__5fProfileRGB_H_ */
